@@ -427,7 +427,8 @@ soup_auth_domain_digest_class_init (SoupAuthDomainDigestClass *digest_class)
 		g_param_spec_pointer (SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK,
 				      "Authentication callback",
 				      "Password-finding callback",
-				      G_PARAM_READWRITE));
+				      G_PARAM_READWRITE |
+				      G_PARAM_STATIC_STRINGS));
 	/**
 	 * SOUP_AUTH_DOMAIN_DIGEST_AUTH_DATA:
 	 *
@@ -444,5 +445,6 @@ soup_auth_domain_digest_class_init (SoupAuthDomainDigestClass *digest_class)
 		g_param_spec_pointer (SOUP_AUTH_DOMAIN_DIGEST_AUTH_DATA,
 				      "Authentication callback data",
 				      "Data to pass to authentication callback",
-				      G_PARAM_READWRITE));
+				      G_PARAM_READWRITE |
+				      G_PARAM_STATIC_STRINGS));
 }
