@@ -3,8 +3,8 @@
  * Copyright (C) 2010 Red Hat, Inc.
  */
 
-#ifndef SOUP_CONNECTION_AUTH_H
-#define SOUP_CONNECTION_AUTH_H 1
+#ifndef __SOUP_CONNECTION_AUTH_H__
+#define __SOUP_CONNECTION_AUTH_H__ 1
 
 #include <libsoup/soup-auth.h>
 
@@ -46,6 +46,10 @@ typedef struct {
 
 GType soup_connection_auth_get_type (void);
 
+SOUP_AVAILABLE_IN_2_58
+gpointer	soup_connection_auth_get_connection_state_for_message
+						(SoupConnectionAuth *auth,
+						 SoupMessage *message);
 G_END_DECLS
 
-#endif /* SOUP_CONNECTION_AUTH_H */
+#endif /* __SOUP_CONNECTION_AUTH_H__ */
