@@ -3,8 +3,8 @@
  * Copyright 2008 Red Hat, Inc.
  */
 
-#ifndef  SOUP_FORM_H
-#define  SOUP_FORM_H 1
+#ifndef  __SOUP_FORM_H__
+#define  __SOUP_FORM_H__ 1
 
 #include <libsoup/soup-types.h>
 #include <libsoup/soup-multipart.h>
@@ -14,6 +14,7 @@ G_BEGIN_DECLS
 #define SOUP_FORM_MIME_TYPE_URLENCODED "application/x-www-form-urlencoded"
 #define SOUP_FORM_MIME_TYPE_MULTIPART  "multipart/form-data"
 
+SOUP_AVAILABLE_IN_2_4
 GHashTable  *soup_form_decode           (const char   *encoded_form);
 SOUP_AVAILABLE_IN_2_26
 GHashTable  *soup_form_decode_multipart (SoupMessage  *msg,
@@ -22,27 +23,34 @@ GHashTable  *soup_form_decode_multipart (SoupMessage  *msg,
 					 char        **content_type,
 					 SoupBuffer  **file);
 
+SOUP_AVAILABLE_IN_2_4
 char        *soup_form_encode           (const char   *first_field,
 					 ...) G_GNUC_NULL_TERMINATED;
+SOUP_AVAILABLE_IN_2_4
 char        *soup_form_encode_hash      (GHashTable   *form_data_set);
+SOUP_AVAILABLE_IN_2_4
 char        *soup_form_encode_datalist  (GData       **form_data_set);
+SOUP_AVAILABLE_IN_2_4
 char        *soup_form_encode_valist    (const char   *first_field,
 					 va_list       args);
 
-#ifndef LIBSOUP_DISABLE_DEPRECATED
+#ifndef SOUP_DISABLE_DEPRECATED
 /* Compatibility with libsoup 2.3.0 */
 #define soup_form_decode_urlencoded      soup_form_decode
 #define soup_form_encode_urlencoded      soup_form_encode_hash
 #define soup_form_encode_urlencoded_list soup_form_encode_datalist
 #endif
 
+SOUP_AVAILABLE_IN_2_4
 SoupMessage *soup_form_request_new                (const char     *method,
 						   const char     *uri,
 						   const char     *first_field,
 						   ...) G_GNUC_NULL_TERMINATED;
+SOUP_AVAILABLE_IN_2_4
 SoupMessage *soup_form_request_new_from_hash      (const char     *method,
 						   const char     *uri,
 						   GHashTable     *form_data_set);
+SOUP_AVAILABLE_IN_2_4
 SoupMessage *soup_form_request_new_from_datalist  (const char     *method,
 						   const char     *uri,
 						   GData         **form_data_set);
@@ -52,4 +60,4 @@ SoupMessage *soup_form_request_new_from_multipart (const char     *uri,
 
 G_END_DECLS
 
-#endif /* SOUP_FORM_H */
+#endif /* __SOUP_FORM_H__ */
